@@ -64,22 +64,22 @@ def team_converter(team_id):
     team_map = {
         1: "Arsenal",
         2: "Aston Villa",
-        3: "Brentford",
-        4: "Brighton",
-        5: "Burnley",
+        3: "Bournemouth",
+        4: "Brentford",
+        5: "Brighton",
         6: "Chelsea",
         7: "Crystal Palace",
         8: "Everton",
-        9: "Leicester",
-        10: "Leeds",
-        11: "Liverpool",
-        12: "Man City",
-        13: "Man Utd",
-        14: "Newcastle",
-        15: "Norwich",
-        16: "Southampton",
-        17: "Spurs",
-        18: "Watford",
+        9: "Fulham",
+        10: "Leicester",
+        11: "Leeds",
+        12: "Liverpool",
+        13: "Man City",
+        14: "Man Utd",
+        15: "Newcastle",
+        16: "Nott'm Forest",
+        17: "Southampton",
+        18: "Spurs",
         19: "West Ham",
         20: "Wolves",
         None: None
@@ -92,22 +92,22 @@ def short_name_converter(team_id):
     short_name_map = {
         1: "ARS",
         2: "AVL",
-        3: "BRE",
-        4: "BHA",
-        5: "BUR",
+        3: "BOU",
+        4: "BRE",
+        5: "BHA",
         6: "CHE",
         7: "CRY",
         8: "EVE",
-        9: "LEI",
-        10: "LEE",
-        11: "LIV",
-        12: "MCI",
-        13: "MUN",
-        14: "NEW",
-        15: "NOR",
-        16: "SOU",
-        17: "TOT",
-        18: "WAT",
+        9: "FUL",
+        10: "LEI",
+        11: "LEE",
+        12: "LIV",
+        13: "MCI",
+        14: "MUN",
+        15: "NEW",
+        16: "NFO",
+        17: "SOU",
+        18: "TOT",
         19: "WHU",
         20: "WOL",
         None: None
